===========
SymPy 0.6.7
===========

17 Mar 2010

* fix a bug where bin/test and bin/doctest would be installed into /usr/bin
* fix an example for recent matplotlib versions
* some fixes for Python 2.4 and 2.5
* try to expand integrand if integration fails
* improved isprime() (pseudoprimes were falsely reported as being prime)
* runtests.py prints less when testing documentation
* ODE code clean-up and fixes
* runtests.py is now more verbose about expected failures to avoid confusion
* update mpmath to version 0.14
* improvements to second quantization module and coupled cluster example
* implement visual ``factorint()``
* implement ``symarray()``: numpy array of sympy symbols
* documentation fixes and some bugfixes
